@@ -1,5 +1,34 @@
 # -*- coding: utf-8 -*-
 import json
+import os
+from importlib import import_module
+
+from pagador import settings
+
+
+class TemplateNaoEncontrado(Exception):
+    pass
+
+
+def caminho_para_template(arquivo, meio_pagamento=None, base_para_diretorio=None):
+    diretorios = getattr(settings, "DIRETORIOS_DOS_TEMPLATES", {})
+    if not diretorios:
+        if meio_pagamento:
+            import_meio_pagamento = settings.LIBS_MEIOS_DE_PAGAMENTO[meio_pagamento]
+            modulo = import_module("{}.{}".format(import_meio_pagamento, "configuracao"))
+            diretorio = os.path.dirname(os.path.realpath(modulo.__file__))
+            return os.path.join(diretorio, "templates", arquivo)
+        if base_para_diretorio:
+            diretorio = os.path.dirname(os.path.realpath(base_para_diretorio))
+            return os.path.join(diretorio, "templates", arquivo)
+    if meio_pagamento and meio_pagamento in diretorios:
+        diretorio = diretorios[meio_pagamento]
+        return os.path.join(diretorio, arquivo)
+    for chave in diretorios:
+        caminho = os.path.join(diretorios[chave], arquivo)
+        if os.path.exists(caminho):
+            return caminho
+    raise TemplateNaoEncontrado("O template para o arquivo {} não foi encontrado.". format(arquivo))
 
 
 class TipoDeCampo(object):
@@ -135,10 +164,11 @@ class ValoresBase(FormularioBase):
         valor = getattr(self.model, self.fields[field].nome)
         if not valor and self.fields[field].valor_padrao:
             valor = self.fields[field].valor_padrao
-        if self.fields[field].tipo == TipoDeCampo.decimal:
-            valor = '{0:.2f}'.format(valor)
-        if self.fields[field].formato == FormatoDeCampo.json and valor:
-            valor = json.dumps(valor)
+        if valor:
+            if self.fields[field].tipo == TipoDeCampo.decimal:
+                valor = '{0:.2f}'.format(valor)
+            if self.fields[field].formato == FormatoDeCampo.json and valor:
+                valor = json.dumps(valor)
         return valor
 
 
